<?php
# dvdisaster: English homepage translation
# Copyright (C) 2004-2010 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3>Placeholder page</h3>

This page has not yet been written.
<pre> </pre>


<font size="-1">
<i>Why does this documentation contain empty pages?</i><p>
We need an empty placeholder page so that hyperlinks to this topic
can already be placed into the documentation.


<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
